@@ -4,7 +4,7 @@ use warnings;
 
 use base 'Catalyst::Controller::RequestToken';
 
-sub form : Local {
+sub form : Local : CreateToken {
     my ( $self, $c ) = @_;
 
     my $html = <<HTML;
@@ -13,49 +13,57 @@ sub form : Local {
 <body>
 FORM
 <form action="confirm" method="post">
+<input type="hidden" name="__token" value="TOKEN"/>
 <input type="submit" name="submit" value="submit"/>
 </form>
 </body>
 </html>
 HTML
 
-$c->response->body($html);
+    my $token = $self->token;
+    $html =~ s/TOKEN/$token/g;
+    $c->response->body($html);
 }
 
-sub confirm : Local : CreateToken {
+sub confirm : Local {
     my ( $self, $c ) = @_;
-    
+
+    #$c->detach('error') unless $self->is_valid_token;
     my $html = <<HTML;
 <html>
 <body>
 CONFIRM
 <form action="complete" method="post">
-<input type="hidden" name="_token" value="TOKEN"/>
+<input type="hidden" name="__token" value="REQUEST"/>
 <input type="submit" name="submit" value="submit"/>
 </form>
 </body>
 </html>
 HTML
-
-my $token = $c->req->param('_token');
-$html =~ s/TOKEN/$token/g;
-
-$c->response->body($html);
+    my $token = $c->req->param('__token');
+    $html =~ s/REQUEST/$token/g;
+    $c->response->body($html);
 }
 
 sub complete : Local : ValidateToken {
     my ( $self, $c ) = @_;
-    
-    my $success = <<HTML;
+
+    $c->detach('error') unless $self->is_valid_token;
+    my $html = <<HTML;
 <html><body>SUCCESS</body></html>
 HTML
-    
-    my $fail = <<HTML;
-<html><body>FAIL</body></html>
+
+    $c->response->body($html);
+}
+
+sub error : Local {
+    my ( $self, $c ) = @_;
+
+    my $html = <<HTML;
+<html><body>INVALID ACCESS</body></html>
 HTML
 
-    my $html = $self->validate_token ? $success : $fail;
-$c->response->body($html);
+    $c->response->body($html);
 }
 
 1;
